#!/bin/bash

# This helper script will handle deploying a kinesis stream
#
# /scripts/deploy-kinesis.sh
#

set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

echo "iam_policy_prefix = \"${externalNamingPrefix}\"" >> ${tfAdditionalVarsFile}

terraform_init

if [ "$IGNORE_SHARD_COUNT" = false ] ; then
  rm kinesis_lifecycle_override.tf
fi

terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"

arnConfigMapName=${namingPrefix}-arn
terraform_get arn arnValue
terraform_get consumer_policy_arn consumerPolicyArnValue
terraform_get producer_policy_arn producerPolicyArnValue
terraform_get shard_mgt_policy_arn shardMgtPolicyArnValue

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  ConsumerPolicy: ${consumerPolicyArnValue}
  ProducerPolicy: ${producerPolicyArnValue}
  ShardManagementPolicy: ${shardMgtPolicyArnValue}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

cprint "$0 done "
